"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import insightproto.proto.common.v1.common_pb2
import insightproto.proto.jobs.v1.job_service_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class JobMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ORG_FIELD_NUMBER: builtins.int
    IDEMPOTENCY_KEY_FIELD_NUMBER: builtins.int
    AETHER_JOB_FIELD_NUMBER: builtins.int
    INSIGHT_JOB_FIELD_NUMBER: builtins.int
    SIMULATOR_JOB_FIELD_NUMBER: builtins.int
    KNOWLEDGE_JOB_FIELD_NUMBER: builtins.int
    CHAT_JOB_FIELD_NUMBER: builtins.int
    id: builtins.str
    """the id of the job"""
    idempotency_key: builtins.str
    """idempotency key to prevent duplicate job processing
    e.g. repo + mr id to prevent aether MR jobs duplication
    """
    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation:
        """the organisation the job is for"""

    @property
    def aether_job(self) -> Global___AetherJob: ...
    @property
    def insight_job(self) -> Global___InsightJob: ...
    @property
    def simulator_job(self) -> Global___SimulatorJob: ...
    @property
    def knowledge_job(self) -> Global___KnowledgeJob: ...
    @property
    def chat_job(self) -> Global___ChatJob: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
        idempotency_key: builtins.str = ...,
        aether_job: Global___AetherJob | None = ...,
        insight_job: Global___InsightJob | None = ...,
        simulator_job: Global___SimulatorJob | None = ...,
        knowledge_job: Global___KnowledgeJob | None = ...,
        chat_job: Global___ChatJob | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["aether_job", b"aether_job", "chat_job", b"chat_job", "insight_job", b"insight_job", "job", b"job", "knowledge_job", b"knowledge_job", "org", b"org", "simulator_job", b"simulator_job"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["aether_job", b"aether_job", "chat_job", b"chat_job", "id", b"id", "idempotency_key", b"idempotency_key", "insight_job", b"insight_job", "job", b"job", "knowledge_job", b"knowledge_job", "org", b"org", "simulator_job", b"simulator_job"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["job", b"job"]) -> typing.Literal["aether_job", "insight_job", "simulator_job", "knowledge_job", "chat_job"] | None: ...

Global___JobMessage: typing_extensions.TypeAlias = JobMessage

@typing.final
class SimulatorJob(google.protobuf.message.Message):
    """SimulatorJob describes a job for the simulator"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    AGENT_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    INSIGHT_AGENT_FIELD_NUMBER: builtins.int
    TEST_SUITE_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    id: builtins.str
    """the id of the job"""
    agent: builtins.str
    """the name of the agent to simulate (e.g. "insight-agent")"""
    test_suite: builtins.str
    """test suite file path for the --inputs flag (e.g. "test_cases/insight-agent/log-agent/opensearch_inputs.yaml")"""
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """DEPRECATED: the inputs to pass (use structured fields below instead)"""

    @property
    def insight_agent(self) -> Global___InsightAgentConfig:
        """Agent-specific configuration"""

    @property
    def error(self) -> insightproto.proto.jobs.v1.job_service_pb2.Error:
        """error that happened from this config"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        agent: builtins.str = ...,
        inputs: collections.abc.Iterable[builtins.str] | None = ...,
        insight_agent: Global___InsightAgentConfig | None = ...,
        test_suite: builtins.str | None = ...,
        error: insightproto.proto.jobs.v1.job_service_pb2.Error | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_error", b"_error", "_insight_agent", b"_insight_agent", "_test_suite", b"_test_suite", "error", b"error", "insight_agent", b"insight_agent", "test_suite", b"test_suite"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_error", b"_error", "_insight_agent", b"_insight_agent", "_test_suite", b"_test_suite", "agent", b"agent", "error", b"error", "id", b"id", "inputs", b"inputs", "insight_agent", b"insight_agent", "test_suite", b"test_suite"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_error", b"_error"]) -> typing.Literal["error"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_insight_agent", b"_insight_agent"]) -> typing.Literal["insight_agent"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_test_suite", b"_test_suite"]) -> typing.Literal["test_suite"] | None: ...

Global___SimulatorJob: typing_extensions.TypeAlias = SimulatorJob

@typing.final
class InsightAgentConfig(google.protobuf.message.Message):
    """Configuration for insight-agent commands"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVESTIGATE_FIELD_NUMBER: builtins.int
    RUN_AGENT_FIELD_NUMBER: builtins.int
    @property
    def investigate(self) -> Global___InvestigateCommand:
        """Command-specific configuration"""

    @property
    def run_agent(self) -> Global___RunAgentCommand: ...
    def __init__(
        self,
        *,
        investigate: Global___InvestigateCommand | None = ...,
        run_agent: Global___RunAgentCommand | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_investigate", b"_investigate", "_run_agent", b"_run_agent", "investigate", b"investigate", "run_agent", b"run_agent"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_investigate", b"_investigate", "_run_agent", b"_run_agent", "investigate", b"investigate", "run_agent", b"run_agent"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_investigate", b"_investigate"]) -> typing.Literal["investigate"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_run_agent", b"_run_agent"]) -> typing.Literal["run_agent"] | None: ...

Global___InsightAgentConfig: typing_extensions.TypeAlias = InsightAgentConfig

@typing.final
class InvestigateCommand(google.protobuf.message.Message):
    """Configuration for "investigate" command"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    query: builtins.str
    def __init__(
        self,
        *,
        query: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["query", b"query"]) -> None: ...

Global___InvestigateCommand: typing_extensions.TypeAlias = InvestigateCommand

@typing.final
class RunAgentCommand(google.protobuf.message.Message):
    """Configuration for "run-agent" command"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGENT_CLASS_FIELD_NUMBER: builtins.int
    SERVER_NAME_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    agent_class: builtins.str
    server_name: builtins.str
    category: builtins.str
    query: builtins.str
    def __init__(
        self,
        *,
        agent_class: builtins.str = ...,
        server_name: builtins.str = ...,
        category: builtins.str = ...,
        query: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["agent_class", b"agent_class", "category", b"category", "query", b"query", "server_name", b"server_name"]) -> None: ...

Global___RunAgentCommand: typing_extensions.TypeAlias = RunAgentCommand

@typing.final
class ChatJob(google.protobuf.message.Message):
    """ChatJob describes a job for chat/conversation operations"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONVERSATION_ID_FIELD_NUMBER: builtins.int
    RESPONSE_ID_FIELD_NUMBER: builtins.int
    HISTORY_FIELD_NUMBER: builtins.int
    CURRENT_MESSAGE_FIELD_NUMBER: builtins.int
    CONTEXT_FIELD_NUMBER: builtins.int
    conversation_id: builtins.str
    """unique conversation/session identifier"""
    response_id: builtins.str
    """the response id for tracking this specific response"""
    @property
    def history(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ChatMessage]:
        """conversation history (previous messages)"""

    @property
    def current_message(self) -> Global___ChatMessage:
        """the current message being processed"""

    @property
    def context(self) -> Global___ChatContext:
        """context linking to investigations/graph nodes"""

    def __init__(
        self,
        *,
        conversation_id: builtins.str = ...,
        response_id: builtins.str = ...,
        history: collections.abc.Iterable[Global___ChatMessage] | None = ...,
        current_message: Global___ChatMessage | None = ...,
        context: Global___ChatContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_context", b"_context", "context", b"context", "current_message", b"current_message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_context", b"_context", "context", b"context", "conversation_id", b"conversation_id", "current_message", b"current_message", "history", b"history", "response_id", b"response_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_context", b"_context"]) -> typing.Literal["context"] | None: ...

Global___ChatJob: typing_extensions.TypeAlias = ChatJob

@typing.final
class ChatMessage(google.protobuf.message.Message):
    """ChatMessage represents a single message in a chat conversation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    role: builtins.str
    """the role of the message sender (e.g. user, assistant, system)"""
    content: builtins.str
    """the message content"""
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """timestamp when message was sent"""

    def __init__(
        self,
        *,
        role: builtins.str = ...,
        content: builtins.str = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "role", b"role", "timestamp", b"timestamp"]) -> None: ...

Global___ChatMessage: typing_extensions.TypeAlias = ChatMessage

@typing.final
class ChatContext(google.protobuf.message.Message):
    """ChatContext provides links to related system entities"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVESTIGATION_ID_FIELD_NUMBER: builtins.int
    NODE_IDS_FIELD_NUMBER: builtins.int
    investigation_id: builtins.str
    """linked investigation id if this chat is part of an investigation"""
    @property
    def node_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """linked graph node ids for context"""

    def __init__(
        self,
        *,
        investigation_id: builtins.str | None = ...,
        node_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_investigation_id", b"_investigation_id", "investigation_id", b"investigation_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_investigation_id", b"_investigation_id", "investigation_id", b"investigation_id", "node_ids", b"node_ids"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_investigation_id", b"_investigation_id"]) -> typing.Literal["investigation_id"] | None: ...

Global___ChatContext: typing_extensions.TypeAlias = ChatContext

@typing.final
class KnowledgeJob(google.protobuf.message.Message):
    """This represents the input to the knowledge job"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    KUBERNETES_FIELD_NUMBER: builtins.int
    ISSUE_FIELD_NUMBER: builtins.int
    TRACE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """the id for tracking"""
    @property
    def source(self) -> insightproto.proto.common.v1.common_pb2.Source:
        """the integration source this is from (e.g. grafana)"""

    @property
    def project(self) -> Global___ProviderProject:
        """if we are a git job then we will contain the project info here"""

    @property
    def author(self) -> Global___Author:
        """user who performed the activity - a null or missing user indicates 'system'"""

    @property
    def kubernetes(self) -> Global___KubernetesConfig:
        """this is the config used for a kubernetes job"""

    @property
    def issue(self) -> Global___IssueConfig:
        """this is the config used for an issue job"""

    @property
    def trace(self) -> Global___TraceConfig:
        """this is the config used for a trace job"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        source: insightproto.proto.common.v1.common_pb2.Source | None = ...,
        project: Global___ProviderProject | None = ...,
        author: Global___Author | None = ...,
        kubernetes: Global___KubernetesConfig | None = ...,
        issue: Global___IssueConfig | None = ...,
        trace: Global___TraceConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_author", b"_author", "_issue", b"_issue", "_kubernetes", b"_kubernetes", "_project", b"_project", "_trace", b"_trace", "author", b"author", "issue", b"issue", "kubernetes", b"kubernetes", "project", b"project", "source", b"source", "trace", b"trace"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_author", b"_author", "_issue", b"_issue", "_kubernetes", b"_kubernetes", "_project", b"_project", "_trace", b"_trace", "author", b"author", "id", b"id", "issue", b"issue", "kubernetes", b"kubernetes", "project", b"project", "source", b"source", "trace", b"trace"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_author", b"_author"]) -> typing.Literal["author"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_issue", b"_issue"]) -> typing.Literal["issue"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_kubernetes", b"_kubernetes"]) -> typing.Literal["kubernetes"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_project", b"_project"]) -> typing.Literal["project"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_trace", b"_trace"]) -> typing.Literal["trace"] | None: ...

Global___KnowledgeJob: typing_extensions.TypeAlias = KnowledgeJob

@typing.final
class TraceConfig(google.protobuf.message.Message):
    """This is the config for a trace job (e.g Datadog, Grafana)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_FILTER_FIELD_NUMBER: builtins.int
    @property
    def service_filter(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """the service names to include"""

    def __init__(
        self,
        *,
        service_filter: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["service_filter", b"service_filter"]) -> None: ...

Global___TraceConfig: typing_extensions.TypeAlias = TraceConfig

@typing.final
class KubernetesConfig(google.protobuf.message.Message):
    """This is the config for a kubernetes job (e.g. AWS EKS)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_FILTER_FIELD_NUMBER: builtins.int
    INCLUDE_SYSTEM_NAMESPACES_FIELD_NUMBER: builtins.int
    CLUSTER_NAME_FIELD_NUMBER: builtins.int
    CLUSTER_CONTEXT_FIELD_NUMBER: builtins.int
    include_system_namespaces: builtins.bool
    """should we process system namespaces"""
    cluster_name: builtins.str
    """the display name of the cluster"""
    cluster_context: builtins.str
    """the context of the cluster to use to when connecting"""
    @property
    def namespace_filter(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """the namespaces to include"""

    def __init__(
        self,
        *,
        namespace_filter: collections.abc.Iterable[builtins.str] | None = ...,
        include_system_namespaces: builtins.bool = ...,
        cluster_name: builtins.str = ...,
        cluster_context: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_context", b"cluster_context", "cluster_name", b"cluster_name", "include_system_namespaces", b"include_system_namespaces", "namespace_filter", b"namespace_filter"]) -> None: ...

Global___KubernetesConfig: typing_extensions.TypeAlias = KubernetesConfig

@typing.final
class IssueConfig(google.protobuf.message.Message):
    """This is the config for an issue job"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """the specific issue to process - if not set process all"""
    def __init__(
        self,
        *,
        id: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_id", b"_id", "id", b"id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_id", b"_id", "id", b"id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_id", b"_id"]) -> typing.Literal["id"] | None: ...

Global___IssueConfig: typing_extensions.TypeAlias = IssueConfig

@typing.final
class AetherJob(google.protobuf.message.Message):
    """AetherJob describes a job for aether to run e.g. a mr review"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    OPERATIONTYPE_FIELD_NUMBER: builtins.int
    ISSUEID_FIELD_NUMBER: builtins.int
    DISCUSSIONID_FIELD_NUMBER: builtins.int
    MERGEREQUESTID_FIELD_NUMBER: builtins.int
    JOBID_FIELD_NUMBER: builtins.int
    NOTEID_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """the id of the job"""
    OperationType: builtins.str
    """the type of job (e.g. mr review)"""
    IssueId: builtins.str
    """the issue id if available for this job"""
    DiscussionId: builtins.str
    """the discussion id if available for this job"""
    MergeRequestId: builtins.str
    """the mr id  if available for this job"""
    JobId: builtins.str
    """the job id  if available for this job"""
    NoteId: builtins.str
    """the note id  if available for this job"""
    @property
    def project(self) -> Global___ProviderProject:
        """the provider (git) project info for the job"""

    @property
    def source(self) -> insightproto.proto.common.v1.common_pb2.Source:
        """the integration source this is from (e.g. grafana)"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        project: Global___ProviderProject | None = ...,
        OperationType: builtins.str = ...,
        IssueId: builtins.str | None = ...,
        DiscussionId: builtins.str | None = ...,
        MergeRequestId: builtins.str | None = ...,
        JobId: builtins.str | None = ...,
        NoteId: builtins.str | None = ...,
        source: insightproto.proto.common.v1.common_pb2.Source | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["DiscussionId", b"DiscussionId", "IssueId", b"IssueId", "JobId", b"JobId", "MergeRequestId", b"MergeRequestId", "NoteId", b"NoteId", "_DiscussionId", b"_DiscussionId", "_IssueId", b"_IssueId", "_JobId", b"_JobId", "_MergeRequestId", b"_MergeRequestId", "_NoteId", b"_NoteId", "project", b"project", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["DiscussionId", b"DiscussionId", "IssueId", b"IssueId", "JobId", b"JobId", "MergeRequestId", b"MergeRequestId", "NoteId", b"NoteId", "OperationType", b"OperationType", "_DiscussionId", b"_DiscussionId", "_IssueId", b"_IssueId", "_JobId", b"_JobId", "_MergeRequestId", b"_MergeRequestId", "_NoteId", b"_NoteId", "id", b"id", "project", b"project", "source", b"source"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_DiscussionId", b"_DiscussionId"]) -> typing.Literal["DiscussionId"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_IssueId", b"_IssueId"]) -> typing.Literal["IssueId"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_JobId", b"_JobId"]) -> typing.Literal["JobId"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_MergeRequestId", b"_MergeRequestId"]) -> typing.Literal["MergeRequestId"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_NoteId", b"_NoteId"]) -> typing.Literal["NoteId"] | None: ...

Global___AetherJob: typing_extensions.TypeAlias = AetherJob

@typing.final
class ProviderProject(google.protobuf.message.Message):
    """ProviderProject describes the remote project source info, e.g. the gitlab project to use"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROVIDER_FIELD_NUMBER: builtins.int
    DEFAULT_BRANCH_NAME_FIELD_NUMBER: builtins.int
    GIT_URL_FIELD_NUMBER: builtins.int
    id: builtins.str
    """the provider project id to use in the api calls e.g. the gitlab id"""
    name: builtins.str
    """the name of the project"""
    default_branch_name: builtins.str
    """the project default branch name"""
    git_url: builtins.str
    """the https git url for the project"""
    @property
    def provider(self) -> Global___Provider:
        """DEPRECATED: use the inline git_url, or source on parent job"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        provider: Global___Provider | None = ...,
        default_branch_name: builtins.str = ...,
        git_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["provider", b"provider"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_branch_name", b"default_branch_name", "git_url", b"git_url", "id", b"id", "name", b"name", "provider", b"provider"]) -> None: ...

Global___ProviderProject: typing_extensions.TypeAlias = ProviderProject

@typing.final
class Provider(google.protobuf.message.Message):
    """DEPRECATED: Type is deprecated should use Source or inlined properties on ProviderProject"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    GITURL_FIELD_NUMBER: builtins.int
    id: builtins.str
    """DEPRECATED: use source.id on job"""
    source: builtins.str
    """DEPRECATED: use source.name on job"""
    gitUrl: builtins.str
    """DEPRECATED: use git_url on ProviderProject"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        source: builtins.str = ...,
        gitUrl: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gitUrl", b"gitUrl", "id", b"id", "source", b"source"]) -> None: ...

Global___Provider: typing_extensions.TypeAlias = Provider

@typing.final
class InsightJob(google.protobuf.message.Message):
    """InsightJob describes a job for insight to investigate"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    id: builtins.str
    """the job id"""
    @property
    def trigger(self) -> Global___Trigger:
        """the job trigger"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        trigger: Global___Trigger | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["trigger", b"trigger"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "trigger", b"trigger"]) -> None: ...

Global___InsightJob: typing_extensions.TypeAlias = InsightJob

@typing.final
class Trigger(google.protobuf.message.Message):
    """Trigger describes where the job has come from (e.g. slack message)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    REFERENCE_ID_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    text: builtins.str
    """the text to feed as the initial input to the agent"""
    reference_id: builtins.str
    """the reference id (eg slack/teams/etc message id)"""
    channel_id: builtins.str
    """the channel id (or similar) - e.g. the id of the slack channel that sourced the message"""
    @property
    def source(self) -> insightproto.proto.common.v1.common_pb2.Source:
        """the source type e.g. slack"""

    @property
    def author(self) -> Global___Author:
        """the author information (name, id, avatar)"""

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the timestamp of the trigger (e.g. the time of the slack message)"""

    def __init__(
        self,
        *,
        source: insightproto.proto.common.v1.common_pb2.Source | None = ...,
        text: builtins.str = ...,
        reference_id: builtins.str | None = ...,
        author: Global___Author | None = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        channel_id: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_channel_id", b"_channel_id", "_reference_id", b"_reference_id", "author", b"author", "channel_id", b"channel_id", "reference_id", b"reference_id", "source", b"source", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_channel_id", b"_channel_id", "_reference_id", b"_reference_id", "author", b"author", "channel_id", b"channel_id", "reference_id", b"reference_id", "source", b"source", "text", b"text", "timestamp", b"timestamp"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_channel_id", b"_channel_id"]) -> typing.Literal["channel_id"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_reference_id", b"_reference_id"]) -> typing.Literal["reference_id"] | None: ...

Global___Trigger: typing_extensions.TypeAlias = Trigger

@typing.final
class Author(google.protobuf.message.Message):
    """Author is the person that authored the trigger"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    name: builtins.str
    """display name of the author"""
    id: builtins.str
    """unique identifier for the author"""
    avatar: builtins.str
    """URL to the author's avatar/profile image"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        id: builtins.str = ...,
        avatar: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["avatar", b"avatar", "id", b"id", "name", b"name"]) -> None: ...

Global___Author: typing_extensions.TypeAlias = Author



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/results/v1/knowledge.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/results/v1/knowledge.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2
from insightproto.proto.results.v1 import timeline_details_pb2 as insightproto_dot_proto_dot_results_dot_v1_dot_timeline__details__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-insightproto/proto/results/v1/knowledge.proto\x12\x1dinsightproto.proto.results.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)insightproto/proto/common/v1/common.proto\x1a\x34insightproto/proto/results/v1/timeline_details.proto\"\x97\x01\n\x0b\x41\x63quisition\x12\n\n\x02id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12\x43\n\tknowledge\x18\x03 \x01(\x0b\x32\x30.insightproto.proto.results.v1.KnowledgeActivity\"\x8b\x04\n\x11KnowledgeActivity\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x06source\x18\x02 \x01(\x0b\x32$.insightproto.proto.common.v1.Source\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12[\n\x06\x61uthor\x18\x05 \x01(\x0b\x32#.insightproto.proto.results.v1.UserB!\x9a\x84\x9e\x03\x1c\x66irestore:\"author,omitempty\"H\x00\x88\x01\x01\x12-\n\tcreatedAt\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x04link\x18\x07 \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"link,omitempty\"H\x01\x88\x01\x01\x12g\n\x08metadata\x18\x08 \x03(\x0b\x32\x30.insightproto.proto.results.v1.KnowledgeMetadataB#\x9a\x84\x9e\x03\x1e\x66irestore:\"metadata,omitempty\"\x12S\n\texpiresAt\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB$\x9a\x84\x9e\x03\x1f\x66irestore:\"expiresAt,omitempty\"B\t\n\x07_authorB\x07\n\x05_link\"B\n\x11KnowledgeMetadata\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x10\n\x08typeName\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x05\x32k\n\x10KnowledgeService\x12W\n\x11KnowledgeAcquired\x12*.insightproto.proto.results.v1.Acquisition\x1a\x16.google.protobuf.EmptyB2Z0github.com/opentrace/insight-proto-go/results/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.results.v1.knowledge_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/opentrace/insight-proto-go/results/v1'
  _globals['_KNOWLEDGEACTIVITY'].fields_by_name['author']._loaded_options = None
  _globals['_KNOWLEDGEACTIVITY'].fields_by_name['author']._serialized_options = b'\232\204\236\003\034firestore:\"author,omitempty\"'
  _globals['_KNOWLEDGEACTIVITY'].fields_by_name['link']._loaded_options = None
  _globals['_KNOWLEDGEACTIVITY'].fields_by_name['link']._serialized_options = b'\232\204\236\003\032firestore:\"link,omitempty\"'
  _globals['_KNOWLEDGEACTIVITY'].fields_by_name['metadata']._loaded_options = None
  _globals['_KNOWLEDGEACTIVITY'].fields_by_name['metadata']._serialized_options = b'\232\204\236\003\036firestore:\"metadata,omitempty\"'
  _globals['_KNOWLEDGEACTIVITY'].fields_by_name['expiresAt']._loaded_options = None
  _globals['_KNOWLEDGEACTIVITY'].fields_by_name['expiresAt']._serialized_options = b'\232\204\236\003\037firestore:\"expiresAt,omitempty\"'
  _globals['_ACQUISITION']._serialized_start=240
  _globals['_ACQUISITION']._serialized_end=391
  _globals['_KNOWLEDGEACTIVITY']._serialized_start=394
  _globals['_KNOWLEDGEACTIVITY']._serialized_end=917
  _globals['_KNOWLEDGEMETADATA']._serialized_start=919
  _globals['_KNOWLEDGEMETADATA']._serialized_end=985
  _globals['_KNOWLEDGESERVICE']._serialized_start=987
  _globals['_KNOWLEDGESERVICE']._serialized_end=1094
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import insightproto.proto.common.v1.common_pb2
import insightproto.proto.jobs.v1.jobs_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SimulatorResultsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORG_FIELD_NUMBER: builtins.int
    SIMULATOR_JOB_FIELD_NUMBER: builtins.int
    AGENT_JOB_IDS_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    COMPLETED_AT_FIELD_NUMBER: builtins.int
    EVALUATION_RESULT_FIELD_NUMBER: builtins.int
    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation:
        """Organization context"""

    @property
    def simulator_job(self) -> insightproto.proto.jobs.v1.jobs_pb2.SimulatorJob:
        """Full simulator job definition (includes job ID and configuration)"""

    @property
    def agent_job_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Multiple agents can be triggered"""

    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Execution timing metadata"""

    @property
    def completed_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def evaluation_result(self) -> Global___EvaluationResult:
        """Evaluation results"""

    def __init__(
        self,
        *,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
        simulator_job: insightproto.proto.jobs.v1.jobs_pb2.SimulatorJob | None = ...,
        agent_job_ids: collections.abc.Iterable[builtins.str] | None = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        completed_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        evaluation_result: Global___EvaluationResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["completed_at", b"completed_at", "evaluation_result", b"evaluation_result", "org", b"org", "simulator_job", b"simulator_job", "started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["agent_job_ids", b"agent_job_ids", "completed_at", b"completed_at", "evaluation_result", b"evaluation_result", "org", b"org", "simulator_job", b"simulator_job", "started_at", b"started_at"]) -> None: ...

Global___SimulatorResultsRequest: typing_extensions.TypeAlias = SimulatorResultsRequest

@typing.final
class EvaluationResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUMMARY_FIELD_NUMBER: builtins.int
    OVERALL_SCORE_FIELD_NUMBER: builtins.int
    ANALYSIS_QUALITY_FIELD_NUMBER: builtins.int
    ACCURACY_ASSESSMENT_FIELD_NUMBER: builtins.int
    AREAS_FOR_IMPROVEMENT_FIELD_NUMBER: builtins.int
    STRENGTHS_FIELD_NUMBER: builtins.int
    summary: builtins.str
    """Summary inherited from AgentResult"""
    overall_score: builtins.int
    """Core evaluation metrics
    0-100,
    """
    analysis_quality: builtins.str
    accuracy_assessment: builtins.str
    areas_for_improvement: builtins.str
    """Optional improvement insights"""
    strengths: builtins.str
    def __init__(
        self,
        *,
        summary: builtins.str = ...,
        overall_score: builtins.int = ...,
        analysis_quality: builtins.str = ...,
        accuracy_assessment: builtins.str = ...,
        areas_for_improvement: builtins.str | None = ...,
        strengths: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_areas_for_improvement", b"_areas_for_improvement", "_strengths", b"_strengths", "areas_for_improvement", b"areas_for_improvement", "strengths", b"strengths"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_areas_for_improvement", b"_areas_for_improvement", "_strengths", b"_strengths", "accuracy_assessment", b"accuracy_assessment", "analysis_quality", b"analysis_quality", "areas_for_improvement", b"areas_for_improvement", "overall_score", b"overall_score", "strengths", b"strengths", "summary", b"summary"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_areas_for_improvement", b"_areas_for_improvement"]) -> typing.Literal["areas_for_improvement"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_strengths", b"_strengths"]) -> typing.Literal["strengths"] | None: ...

Global___EvaluationResult: typing_extensions.TypeAlias = EvaluationResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import insightproto.proto.common.v1.common_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _JobType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _JobTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_JobType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    JOB_TYPE_UNSPECIFIED: _JobType.ValueType  # 0
    JOB_TYPE_INSIGHT: _JobType.ValueType  # 1
    """Insight investigation jobs"""
    JOB_TYPE_AETHER: _JobType.ValueType  # 2
    """Aether MR review jobs"""
    JOB_TYPE_SIMULATOR: _JobType.ValueType  # 3
    """Simulator evaluation jobs"""
    JOB_TYPE_KNOWLEDGE: _JobType.ValueType  # 4
    """Knowledge acquisition jobs"""
    JOB_TYPE_CHAT: _JobType.ValueType  # 5
    """Chat/conversation jobs"""

class JobType(_JobType, metaclass=_JobTypeEnumTypeWrapper):
    """JobType defines the type of job"""

JOB_TYPE_UNSPECIFIED: JobType.ValueType  # 0
JOB_TYPE_INSIGHT: JobType.ValueType  # 1
"""Insight investigation jobs"""
JOB_TYPE_AETHER: JobType.ValueType  # 2
"""Aether MR review jobs"""
JOB_TYPE_SIMULATOR: JobType.ValueType  # 3
"""Simulator evaluation jobs"""
JOB_TYPE_KNOWLEDGE: JobType.ValueType  # 4
"""Knowledge acquisition jobs"""
JOB_TYPE_CHAT: JobType.ValueType  # 5
"""Chat/conversation jobs"""
Global___JobType: typing_extensions.TypeAlias = JobType

@typing.final
class JobIdentifier(google.protobuf.message.Message):
    """============================================
    Core Identifiers
    ============================================

    JobIdentifier uniquely identifies a job across all types
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """Job ID"""
    type: Global___JobType.ValueType
    """Job type"""
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
        type: Global___JobType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["job_id", b"job_id", "type", b"type"]) -> None: ...

Global___JobIdentifier: typing_extensions.TypeAlias = JobIdentifier

@typing.final
class JobEvent(google.protobuf.message.Message):
    """============================================
    Job Events
    ============================================

    JobEvent represents an event that occurred during job processing
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORG_FIELD_NUMBER: builtins.int
    JOB_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    AGENT_FIELD_NUMBER: builtins.int
    THOUGHT_FIELD_NUMBER: builtins.int
    TOOL_CALL_FIELD_NUMBER: builtins.int
    TOOL_RESULT_FIELD_NUMBER: builtins.int
    AGENT_STARTED_FIELD_NUMBER: builtins.int
    AGENT_STOPPED_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    CHAT_CONTENT_FIELD_NUMBER: builtins.int
    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation:
        """The owner organisation"""

    @property
    def job(self) -> Global___JobIdentifier:
        """The job this event belongs to"""

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """When this event occurred"""

    @property
    def agent(self) -> Global___Agent:
        """The agent this event is from"""

    @property
    def thought(self) -> Global___ThoughtEvent:
        """Agent reasoning/thinking"""

    @property
    def tool_call(self) -> Global___ToolCallEvent:
        """Tool invocation started"""

    @property
    def tool_result(self) -> Global___ToolResultEvent:
        """Tool execution completed"""

    @property
    def agent_started(self) -> Global___AgentStartedEvent:
        """Sub-agent started"""

    @property
    def agent_stopped(self) -> Global___AgentStoppedEvent:
        """Sub-agent stopped"""

    @property
    def progress(self) -> Global___ProgressEvent:
        """Progress update"""

    @property
    def chat_content(self) -> Global___ChatContentEvent:
        """Streamed chat content"""

    def __init__(
        self,
        *,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
        job: Global___JobIdentifier | None = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        agent: Global___Agent | None = ...,
        thought: Global___ThoughtEvent | None = ...,
        tool_call: Global___ToolCallEvent | None = ...,
        tool_result: Global___ToolResultEvent | None = ...,
        agent_started: Global___AgentStartedEvent | None = ...,
        agent_stopped: Global___AgentStoppedEvent | None = ...,
        progress: Global___ProgressEvent | None = ...,
        chat_content: Global___ChatContentEvent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["agent", b"agent", "agent_started", b"agent_started", "agent_stopped", b"agent_stopped", "chat_content", b"chat_content", "event", b"event", "job", b"job", "org", b"org", "progress", b"progress", "thought", b"thought", "timestamp", b"timestamp", "tool_call", b"tool_call", "tool_result", b"tool_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["agent", b"agent", "agent_started", b"agent_started", "agent_stopped", b"agent_stopped", "chat_content", b"chat_content", "event", b"event", "job", b"job", "org", b"org", "progress", b"progress", "thought", b"thought", "timestamp", b"timestamp", "tool_call", b"tool_call", "tool_result", b"tool_result"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["event", b"event"]) -> typing.Literal["thought", "tool_call", "tool_result", "agent_started", "agent_stopped", "progress", "chat_content"] | None: ...

Global___JobEvent: typing_extensions.TypeAlias = JobEvent

@typing.final
class Agent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """the name of the agent e.g. knowledge_agent.KnowledgeAgent"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

Global___Agent: typing_extensions.TypeAlias = Agent

@typing.final
class ThoughtEvent(google.protobuf.message.Message):
    """ThoughtEvent represents agent reasoning or thinking"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THOUGHT_FIELD_NUMBER: builtins.int
    thought: builtins.str
    """The thought/reasoning content"""
    def __init__(
        self,
        *,
        thought: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["thought", b"thought"]) -> None: ...

Global___ThoughtEvent: typing_extensions.TypeAlias = ThoughtEvent

@typing.final
class ToolCallEvent(google.protobuf.message.Message):
    """ToolCallEvent represents a tool being invoked"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOOL_CALL_ID_FIELD_NUMBER: builtins.int
    TOOL_NAME_FIELD_NUMBER: builtins.int
    MCP_SERVER_FIELD_NUMBER: builtins.int
    ARGUMENTS_FIELD_NUMBER: builtins.int
    tool_call_id: builtins.str
    """Unique identifier for this tool call"""
    tool_name: builtins.str
    """The name of the tool being called"""
    mcp_server: builtins.str
    """The MCP server name if this is an MCP tool"""
    @property
    def arguments(self) -> google.protobuf.struct_pb2.Struct:
        """The arguments passed to the tool"""

    def __init__(
        self,
        *,
        tool_call_id: builtins.str = ...,
        tool_name: builtins.str = ...,
        mcp_server: builtins.str | None = ...,
        arguments: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_mcp_server", b"_mcp_server", "arguments", b"arguments", "mcp_server", b"mcp_server"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_mcp_server", b"_mcp_server", "arguments", b"arguments", "mcp_server", b"mcp_server", "tool_call_id", b"tool_call_id", "tool_name", b"tool_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_mcp_server", b"_mcp_server"]) -> typing.Literal["mcp_server"] | None: ...

Global___ToolCallEvent: typing_extensions.TypeAlias = ToolCallEvent

@typing.final
class ToolResultEvent(google.protobuf.message.Message):
    """ToolResultEvent represents the result of a tool execution"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOOL_CALL_ID_FIELD_NUMBER: builtins.int
    SUCCESS_FIELD_NUMBER: builtins.int
    RESULT_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    DURATION_MS_FIELD_NUMBER: builtins.int
    tool_call_id: builtins.str
    """The tool call ID this result corresponds to"""
    success: builtins.bool
    """Whether the tool execution was successful"""
    error_message: builtins.str
    """Error message (if failed)"""
    duration_ms: builtins.int
    """Execution duration in milliseconds"""
    @property
    def result(self) -> google.protobuf.struct_pb2.Struct:
        """The result data (if successful)"""

    def __init__(
        self,
        *,
        tool_call_id: builtins.str = ...,
        success: builtins.bool = ...,
        result: google.protobuf.struct_pb2.Struct | None = ...,
        error_message: builtins.str | None = ...,
        duration_ms: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_error_message", b"_error_message", "_result", b"_result", "error_message", b"error_message", "result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_error_message", b"_error_message", "_result", b"_result", "duration_ms", b"duration_ms", "error_message", b"error_message", "result", b"result", "success", b"success", "tool_call_id", b"tool_call_id"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_error_message", b"_error_message"]) -> typing.Literal["error_message"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_result", b"_result"]) -> typing.Literal["result"] | None: ...

Global___ToolResultEvent: typing_extensions.TypeAlias = ToolResultEvent

@typing.final
class AgentStartedEvent(google.protobuf.message.Message):
    """AgentStartedEvent represents a sub-agent being spawned"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GOAL_FIELD_NUMBER: builtins.int
    goal: builtins.str
    """The goal/task assigned to this agent"""
    def __init__(
        self,
        *,
        goal: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_goal", b"_goal", "goal", b"goal"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_goal", b"_goal", "goal", b"goal"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_goal", b"_goal"]) -> typing.Literal["goal"] | None: ...

Global___AgentStartedEvent: typing_extensions.TypeAlias = AgentStartedEvent

@typing.final
class AgentStoppedEvent(google.protobuf.message.Message):
    """AgentStoppedEvent represents a sub-agent completing"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERROR_FIELD_NUMBER: builtins.int
    error: builtins.str
    """Error message if the agent failed"""
    def __init__(
        self,
        *,
        error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_error", b"_error", "error", b"error"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_error", b"_error", "error", b"error"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_error", b"_error"]) -> typing.Literal["error"] | None: ...

Global___AgentStoppedEvent: typing_extensions.TypeAlias = AgentStoppedEvent

@typing.final
class ProgressEvent(google.protobuf.message.Message):
    """ProgressEvent represents a progress update"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    PERCENT_FIELD_NUMBER: builtins.int
    message: builtins.str
    """Human-readable progress message"""
    percent: builtins.int
    """Progress percentage (0-100)"""
    def __init__(
        self,
        *,
        message: builtins.str = ...,
        percent: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_percent", b"_percent", "percent", b"percent"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_percent", b"_percent", "message", b"message", "percent", b"percent"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_percent", b"_percent"]) -> typing.Literal["percent"] | None: ...

Global___ProgressEvent: typing_extensions.TypeAlias = ProgressEvent

@typing.final
class ChatContentEvent(google.protobuf.message.Message):
    """ChatContentEvent represents streamed content from an AI response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    COMPLETE_FIELD_NUMBER: builtins.int
    CONVERSATION_ID_FIELD_NUMBER: builtins.int
    RESPONSE_ID_FIELD_NUMBER: builtins.int
    text: builtins.str
    """The text content being streamed"""
    sequence: builtins.int
    """Sequence number for ordering"""
    complete: builtins.bool
    """Marks this message as complete"""
    conversation_id: builtins.str
    """the id of the conversation"""
    response_id: builtins.str
    """response id of the response to update"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        sequence: builtins.int | None = ...,
        complete: builtins.bool = ...,
        conversation_id: builtins.str = ...,
        response_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_sequence", b"_sequence", "sequence", b"sequence"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_sequence", b"_sequence", "complete", b"complete", "conversation_id", b"conversation_id", "response_id", b"response_id", "sequence", b"sequence", "text", b"text"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_sequence", b"_sequence"]) -> typing.Literal["sequence"] | None: ...

Global___ChatContentEvent: typing_extensions.TypeAlias = ChatContentEvent



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/events/v1/insight.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/events/v1/insight.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2
from insightproto.proto.jobs.v1 import jobs_pb2 as insightproto_dot_proto_dot_jobs_dot_v1_dot_jobs__pb2
from insightproto.proto.results.v1 import results_pb2 as insightproto_dot_proto_dot_results_dot_v1_dot_results__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*insightproto/proto/events/v1/insight.proto\x12\x1cinsightproto.proto.events.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)insightproto/proto/common/v1/common.proto\x1a%insightproto/proto/jobs/v1/jobs.proto\x1a+insightproto/proto/results/v1/results.proto\"\xc8\x02\n\x0fInsightComplete\x12\n\n\x02id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12\x34\n\x07trigger\x18\x03 \x01(\x0b\x32#.insightproto.proto.jobs.v1.Trigger\x12,\n\x08\x63losedAt\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tcreatedAt\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05title\x18\x06 \x01(\t\x12\x0f\n\x07summary\x18\x07 \x01(\t\x12=\n\nhypotheses\x18\x08 \x01(\x0b\x32).insightproto.proto.results.v1.HypothesisB1Z/github.com/opentrace/insight-proto-go/events/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.events.v1.insight_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/opentrace/insight-proto-go/events/v1'
  _globals['_INSIGHTCOMPLETE']._serialized_start=237
  _globals['_INSIGHTCOMPLETE']._serialized_end=565
# @@protoc_insertion_point(module_scope)
